==> arq-2.8.4-sources.jar: com/hp/hpl/jena/sparql/core/DataFormat.java <==
/*
 * (c) Copyright 2005, 2006, 2007, 2008, 2009 Hewlett-Packard Development Company, LP
 * All rights reserved.
 * [See end of file]
 */

package com.hp.hpl.jena.sparql.core;

import com.hp.hpl.jena.sparql.util.Symbol;
import com.hp.hpl.jena.sparql.util.TranslationTable;
import com.hp.hpl.jena.util.FileUtils;


public class DataFormat extends Symbol
{
    public static final DataFormat langNTriples
                    = new DataFormat(FileUtils.langNTriple) ;
    
    public static final DataFormat langXML
                    = new DataFormat(FileUtils.langXML ) ;
    
    public static final DataFormat langXMLAbbrev
                    = new DataFormat(FileUtils.langXMLAbbrev) ;
    
    public static final DataFormat langTurtle
                    = new DataFormat(FileUtils.langTurtle ) ;
    
    public static final DataFormat langN3
                    = new DataFormat(FileUtils.langN3 ) ;

    public static TranslationTable dataSyntaxNames = new TranslationTable(true) ;
    static {
        dataSyntaxNames.put("nt",           langNTriples ) ;
        dataSyntaxNames.put("n3",           langN3 ) ;
        dataSyntaxNames.put("n-triples",    langNTriples ) ;
        dataSyntaxNames.put("n-triple",     langNTriples ) ;
        dataSyntaxNames.put("xml",          langXML ) ;
        dataSyntaxNames.put("rdf",          langXML ) ; 
        dataSyntaxNames.put("rdf/xml",      langXML ) ; 
        dataSyntaxNames.put("turtle",       langTurtle ) ;
    }
    
    protected DataFormat(String s) { super(s) ; }
    protected DataFormat(DataFormat s) { super(s) ; }
    
    /** Short name to proper name (symbol)
     * 
     */
    public static DataFormat lookup(String s)
    {
        return (DataFormat)dataSyntaxNames.lookup(s) ;
    }
}

/*
 * (c) Copyright 2005, 2006, 2007, 2008, 2009 Hewlett-Packard Development Company, LP
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

==> arq-2.8.8-sources.jar: com/hp/hpl/jena/sparql/core/DataFormat.java <==
/*
 * (c) Copyright 2005, 2006, 2007, 2008, 2009 Hewlett-Packard Development Company, LP
 * All rights reserved.
 * [See end of file]
 */

package com.hp.hpl.jena.sparql.core;

import com.hp.hpl.jena.sparql.util.Symbol ;
import com.hp.hpl.jena.sparql.util.TranslationTable ;
import com.hp.hpl.jena.util.FileUtils ;


public class DataFormat extends Symbol
{
    public static final DataFormat langNTriples
                    = new DataFormat(FileUtils.langNTriple) ;
    
    public static final DataFormat langXML
                    = new DataFormat(FileUtils.langXML ) ;
    
    public static final DataFormat langXMLAbbrev
                    = new DataFormat(FileUtils.langXMLAbbrev) ;
    
    public static final DataFormat langTurtle
                    = new DataFormat(FileUtils.langTurtle ) ;
    
    public static final DataFormat langN3
                    = new DataFormat(FileUtils.langN3 ) ;

    public static TranslationTable<DataFormat> dataSyntaxNames = new TranslationTable<DataFormat>(true) ;
    static {
        dataSyntaxNames.put("nt",           langNTriples ) ;
        dataSyntaxNames.put("n3",           langN3 ) ;
        dataSyntaxNames.put("n-triples",    langNTriples ) ;
        dataSyntaxNames.put("n-triple",     langNTriples ) ;
        dataSyntaxNames.put("xml",          langXML ) ;
        dataSyntaxNames.put("rdf",          langXML ) ; 
        dataSyntaxNames.put("rdf/xml",      langXML ) ; 
        dataSyntaxNames.put("turtle",       langTurtle ) ;
    }
    
    protected DataFormat(String s) { super(s) ; }
    protected DataFormat(DataFormat s) { super(s) ; }
    
    /** Short name to proper name (symbol)
     * 
     */
    public static DataFormat lookup(String s)
    {
        return dataSyntaxNames.lookup(s) ;
    }
}

/*
 * (c) Copyright 2005, 2006, 2007, 2008, 2009 Hewlett-Packard Development Company, LP
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
